@@ -27,7 +27,6 @@
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
 #include <pygobject.h>
 #include <pygtk/pygtk.h>
-#include "pygnomevfs.h"
 
 void pynautilus_register_classes (PyObject *d);
 void pynautilus_add_constants(PyObject *module, const gchar *strip_prefix);
@@ -39,14 +38,14 @@ initnautilus(void)
 {
     PyObject *m, *d;
     
-    if (!g_getenv("INSIDE_NAUTILUS_PYTHON")) {
-	Py_FatalError("This module can only be used from nautilus");
-	return;
+    if (!g_getenv("INSIDE_NAUTILUS_PYTHON"))
+    {
+	    Py_FatalError("This module can only be used from nautilus");
+	    return;
     }
 	
     init_pygobject ();
     init_pygtk ();
-    init_pygnomevfs();
 
     m = Py_InitModule ("nautilus", pynautilus_functions);
     d = PyModule_GetDict (m);
